Creating and editing input files
================================

The EDIT INPUT FILES section of the main user interface menu activates facilities for creating, examining, modifying, printing or deleting all the necessary input files for running the model.

Menus for Editing Input Files

All the procedures for editing the various input files have similar menu systems:

The File menu offers the following commands:

Open File - Activates the Open File dialog box (Ctrl + O may also be used).  See:  The Open File Dialog for Input Files .

Print Setup  -   Sets the printer (Ctrl + S may also be used).

Exit -Exits this program and returns to the main user interface (Alt / F4 may also be used).

The Help menu offers the following commands, which provide you assistance with this application:

Help Topics - Initiates the help system (the F1 function key may also be used).

About ... - Displays information about this application.

The following are the input file types. Click each for specific information.


Profile files

Agricultural Input Files

Weather Input Files

Plant Map Adjustment Files

Soil Hydrology Files

Initial Soil Data Files
